Kaidoku: Player, solver and creater of sudoku puzzles
=======================

Kaidoku can solve sudoku puzzles as shown in the figure, play with the puzzles and create sudoku puzzles with a command-line interface.

Kaidoku is a

- player of sudoku. You can play original sudoku puzzles of various level of difficulty with command line interface. You can get hints when you want.
- solver of sudoku. It can solve a sudoku puzzle and show the procedure of solving a sudoku puzzle with various logics. It evaluates if a given puzzle is valid sudoku with unique solution.
- creater of sudoku. It can create new sudoku puzzles. The puzzles shipped with this program was created by the program itself. 

Online player is also available at
https://sekika.github.io/kaidoku/sudoku

Project Home Page
---------------------

https://sekika.github.io/kaidoku/
